@@ -37,11 +37,13 @@
 #include <netdb.h>
 #include <net/if.h>
 #include <arpa/inet.h>
+#include <netinet/in.h>
 
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-lowlevel.h>
 
 #include "vino-util.h"
+#include "vino-mdns.h"
 #ifdef VINO_ENABLE_HTTP_SERVER
 #include "vino-http.h"
 #endif
@@ -125,7 +127,7 @@ get_local_hostname (VinoDBusListener *listener)
   g_hash_table_iter_init (&iter, ipv4);
   while (g_hash_table_iter_next (&iter, &key, &value))
     {
-      if (strcmp (key, "lo") == 0)
+      if (strncmp (key, "lo", 2) == 0)
 	continue;
       retval = g_strdup (value);
       goto the_end;
@@ -134,7 +136,7 @@ get_local_hostname (VinoDBusListener *listener)
   g_hash_table_iter_init (&iter, ipv6);
   while (g_hash_table_iter_next (&iter, &key, &value))
     {
-      if (strcmp (key, "lo") == 0)
+      if (strncmp (key, "lo", 2) == 0)
 	continue;
       retval = g_strdup (value);
       goto the_end;
@@ -243,6 +245,7 @@ static const char * introspect_xml =
   "  <interface name=\"org.gnome.VinoScreen\">\n"
   "    <method name=\"GetInternalData\">\n"
   "      <arg name=\"hostname\" direction=\"out\" type=\"s\"/>\n"
+  "      <arg name=\"avahi_hostname\" direction=\"out\" type=\"s\"/>\n"
   "      <arg name=\"port\" direction=\"out\" type=\"d\"/>\n"
   "    </method>\n"
   "    <method name=\"GetExternalPort\">\n"
@@ -320,6 +323,7 @@ vino_dbus_listener_handle_get_internal_data (VinoDBusListener *listener,
   DBusMessage *reply;
   gint        port;
   char        *host = NULL;
+  const char  *avahi_host;
 
   if (!(reply = dbus_message_new_method_return (message)))
     goto oom;
@@ -331,8 +335,10 @@ vino_dbus_listener_handle_get_internal_data (VinoDBusListener *listener,
 #endif
 
   host = get_local_hostname (listener);
+  avahi_host = vino_mdns_get_hostname ();
   if (!dbus_message_append_args (reply,
                                  DBUS_TYPE_STRING, &host,
+                                 DBUS_TYPE_STRING, &avahi_host,
                                  DBUS_TYPE_INT32, &port,
                                  DBUS_TYPE_INVALID))
     goto oom;
