@@ -272,9 +272,9 @@ vino_prompt_setup_icons (VinoPrompt *prompt,
   g_assert (prompt->priv->sharing_icon != NULL);
 
   gtk_window_set_icon_name (GTK_WINDOW (prompt->priv->dialog),
-			    "gnome-remote-desktop");
+			    "preferences-desktop-remote-desktop");
   gtk_image_set_from_icon_name (GTK_IMAGE (prompt->priv->sharing_icon),
-				"gnome-remote-desktop", GTK_ICON_SIZE_DIALOG);
+				"preferences-desktop-remote-desktop", GTK_ICON_SIZE_DIALOG);
 
 #undef ICON_SIZE_STANDARD
 }
@@ -349,7 +349,7 @@ vino_prompt_display (VinoPrompt   *prompt,
 
   prompt->priv->current_client = rfb_client;
 
-  gtk_widget_show (prompt->priv->dialog);
+  gtk_widget_show_all (prompt->priv->dialog);
 
   dprintf (PROMPT, "Prompting for client %p\n", rfb_client);
 
