@@ -85,9 +85,11 @@ int                  vino_server_get_alternative_port     (VinoServer     *serve
 void                 vino_server_set_alternative_port     (VinoServer     *server,
 							   int             alternative_port);
 int                  vino_server_get_port                 (VinoServer     *server);
-void                 vino_server_set_local_only           (VinoServer     *server,
-							   gboolean        local_only);
-gboolean             vino_server_get_local_only           (VinoServer     *server);
+int                  vino_server_get_external_port        (VinoServer     *server);
+
+void                 vino_server_set_network_interface    (VinoServer     *server,
+                                                           const char     *network_interface);
+G_CONST_RETURN char *vino_server_get_network_interface    (VinoServer     *server);
 void                 vino_server_set_require_encryption   (VinoServer     *server,
 							   gboolean        require_encryption);
 gboolean             vino_server_get_require_encryption   (VinoServer     *server);
@@ -105,8 +107,16 @@ void                 vino_server_set_disable_background   (VinoServer     *serve
                                                            gboolean        disable_background);
 gboolean             vino_server_get_disable_background   (VinoServer     *server);
 
+void                 vino_server_set_use_upnp             (VinoServer     *server,
+                                                           gboolean        use_upnp);
+gboolean             vino_server_get_use_upnp             (VinoServer     *server);
+
+void                 vino_server_set_disable_xdamage      (VinoServer     *server,
+                                                           gboolean        disable_xdamage);
+gboolean             vino_server_get_disable_xdamage      (VinoServer     *server);
+
 #include "vino-status-icon.h"
-VinoStatusIcon      *vino_server_get_status_icon          (VinoServer     *server);
+VinoStatusIcon      *vino_server_get_status_icon          (VinoServer      *server);
 
 G_CONST_RETURN char *vino_client_get_hostname (VinoClient *client);
 void                 vino_client_disconnect   (VinoClient *client);
